==> bbtoolbar_v1.0.tar.gz: bbtoolbar/res/bbtoolbar.js <==
//## DEFAULT CONFIG
bbtConfiguration={
	'enEn' : true,
	'enCo' : true,
	'emEnTB' : true,
	'emCoTB' : true,
	'emSet' : '',
	'blog_url' : './',
	'plugin_url' : './fp-plugins/bbtoolbar/',
	'tag' : false
};
bbtEmoticons={
}
//## EOF DEFAULT CONFIG

/**
 * This function creates a button with the standard DOM.
 *
 * @param string value: The value of the button
 * @param string name: The name of the button
 * @param string title: The title of the button
 * @return object: The button
 */
function bbtCreateButton(value, name, title) {
	name='bbtoolbar_'+name;

	button=document.createElement('input');
	button.setAttribute('value', value);
	button.setAttribute('name', name);
	button.setAttribute('title', title);
	button.setAttribute('type', 'button');

	return button;
}

/**
 * This function is the onclick handler for the buttons.
 */
function bbtOnclick() {
	// The pressed tag
	tag=$(this).attr('name').substr(10);

	// The target textarea
	target='textarea#content';

	if('undefined'!=typeof bbtCustomFunctions) {
		if(tag in bbtCustomFunctions) {
			if(!bbtCustomFunctions[tag](target)) {
				return false;
			}
		}
	}

	/*
	 * Complicated tags:
	 * color
	 * size
	 * url
	 * img
	 * video
	 * list --> Not implemented
	 * * --> Not implemented
	 * align
	 */
	switch(tag) {
		case 'img':
			bbtImgBox(target);
			break;
		case 'url':
			bbtUrlBox(target);
			break;
		default:
			$(target).insertAtCursor('['+tag+']', '[/'+tag+']');
			break;
	}

	return false;
}

/**
 * This function creates the toolbar of the comments.
 *
 * @param mixed target: The target of the form
 */
function bbtCommentToolbar(target) {
	// Create the place where insert buttons
	newelements=$('<div class="bbtoolbar comm_toolbar"></div>');
	newelements.insertBefore(target);

	buttons=[
		bbtCreateButton('B', 'b', '~~bold~~'), 
		bbtCreateButton('I', 'i', '~~italic~~'),
		bbtCreateButton('U', 'u', '~~underline~~'),
		bbtCreateButton('Del', 'del', '~~del~~'),
		bbtCreateButton('Quote', 'quote', '~~quote~~'),
		bbtCreateButton('Code', 'code', '~~code~~'),
	]

	if('undefined'!=typeof bbtCustomComment) {
		buttons=buttons.concat(bbtCustomComment);
	}

	// IE Complains. Fuck IE!
	//$(buttons).click(bbtOnclick).appendTo(newelements);
	$(buttons).each(function() {
			$(this).click(bbtOnclick)
		}).appendTo(newelements);
}

/**
 * This function creates the toolbar of the admin panel.
 */
function bbtAdminToolbar() {
	// Create the place where insert buttons
	newelements=$('<div class="bbtoolbar admin_toolbar"></div>');
	newelements.appendTo('.bbtoolbar_placeholder');

	buttons=[
		bbtCreateButton('B', 'b', '~~bold~~'), 
		bbtCreateButton('I', 'i', '~~italic~~'),
		bbtCreateButton('U', 'u', '~~underline~~'),
		bbtCreateButton('Del', 'del', '~~del~~'),
		bbtCreateButton('Quote', 'quote', '~~quote~~'),
		bbtCreateButton('Code', 'code', '~~code~~'),
		bbtCreateButton('Img', 'img', '~~image~~'),
		bbtCreateButton('URL', 'url', '~~url~~'),
		// 'hr','h2','h3','h4','h5','h6' --> I won't do them
		// list, * --> I won't do them
		// video --> I won't to it
		// align, color, size --> Should I do them?
	]

	if(bbtConfiguration.tag) {
		buttons[buttons.length]=bbtCreateButton('Tag', 'tag', '~~tag~~');
	}

	if('undefined'!=typeof bbtCustomAdmin) {
		buttons=buttons.concat(bbtCustomAdmin);
	}

	// IE Complains. Fuck IE!
	//$(buttons).click(bbtOnclick).appendTo(newelements);
	$(buttons).each(function() {
			$(this).click(bbtOnclick)
		}).appendTo(newelements);
}

/**
 * This function is the handler for the event
 * click of the emoticons.
 */
function bbtEclick() {
	alt=$(this).attr('alt');
	$('textarea#content').insertAtCursor(' '+alt+' ', '', false);
}

/**
 * This function creates the toolbar of the emoticons.
 *
 * @param mixed where: Where to add it.
 */
function bbtEmoticonsList(where) {
	if($(where).length<1) {
		return;
	}

	newelements=$('<div class="bbtoolbar emo_toolbar"></div>');

	for(i in bbtEmoticons) {
		image=document.createElement('img');
		image.setAttribute('alt', i);
		image.setAttribute('title', i);
		image.setAttribute('src', bbtConfiguration.plugin_url+'e_'+bbtConfiguration.emSet+'/'+bbtEmoticons[i]);
		$(image).click(bbtEclick).appendTo(newelements);
	}

	$(where).replaceWith(newelements);
}

/**
 * We start all the mechanism just when dom is ready.
 */
window.jQuery(document).ready(function() {
	// It's better making the search once
	isComment=$('#commentform').length>0;

	// The comments target: this is because of two different forms!
	target=$('#commentform .comment-content');
	alt_target=$('#commentform fieldset[id!=comment-userdata]:first');
	if(target.length==0 && alt_target.length>0) {
		target=alt_target;
	}

	if(isComment && bbtConfiguration.enCo) {
		bbtCommentToolbar(target);
	}

	if(isComment && bbtConfiguration.emCoTB) {
		placeholder=$('<div></div>').insertBefore(target);
		bbtEmoticonsList(placeholder);
	}

	// Same as above
	isAdmin=$('form[name=admin_entry_write]').length>0;

	if(isAdmin && bbtConfiguration.enEn) {
		bbtAdminToolbar();
	}

	if(isAdmin && bbtConfiguration.emEnTB) {
		placeholder=$('<div></div>').appendTo('.bbtoolbar_placeholder');
		bbtEmoticonsList(placeholder);
	}

});

/**
 * This function adds the text to the current position of the cursor.
 *
 * Thanks to phpMyAdmin that wrote it in js/functions.js
 * Thanks also to http://www.devland.it/cs/blogs/marco-del-gatto/archive/
 *    2010/09/14/funzione-jquery-per-inserire-testo-alla-posizione-del-cursore-di-una-textarea.aspx
 * because it didn't work without the $(this).each.
 * Thanks also to http://stackoverflow.com/questions/499126/jquery-set-cursor-position-in-text-area
 * because I've taken from here the position of the cursor.
 * Thanks also to http://web.archive.org/web/20080214051356/http://www.csie.ntu.edu.tw/~b88039/
 * html/jslib/caret.html : it helped me a lot with the Internet Explorer support
 *
 * @param string before: The text to insert before
 * @param string after: The text to insert after
 * @param boolean preserve: Preserve the selection? By default true
 */
window.jQuery.fn.insertAtCursor=function(before, after, preserve) {
	preserve=preserve!=false && undefined!=typeof preserve;

	$(this).each(function() {
		myField=this;

		if(myField.selectionStart || myField.selectionStart==0) {
			//MOZILLA/NETSCAPE and DOM support
			var startPos = myField.selectionStart;
			var endPos = myField.selectionEnd;

			if(startPos==0 && endPos==0) {
				startPos=myField.value.length;
				endPos=myField.value.length;
			}

			startText=myField.value.substring(0, startPos);
			endText=myField.value.substring(endPos, myField.value.length);

			if(startPos==endPos || !preserve) {
				current='';
				pos=-after.length;
			} else {
				current=myField.value.substring(startPos, endPos);
				pos=current.length;
			}

			myField.value=startText+before+current+after+endText;

			pos+=startPos+before.length+current.length+after.length;
			myField.focus();
			myField.setSelectionRange(pos, pos)
		} else if(document.selection) {
			// IE Support
			myField.focus();
			sel = document.selection.createRange();
			
			if(sel.text.length==0 || !preserve) {
				current='';
				pos=-after.length;
			} else {
				current=sel.text;
				pos=current.length;
			}

			sel.text = before+current+after;

			// Get the position of the cursor
			var c="\001", dul=sel.duplicate(), len=0;
			myField.value.replace('&', '&amp;');
			myField.value.replace(c, '&#001;');
			dul.moveToElementText(myField);
			sel.text=c;
			len=dul.text.indexOf(c)+1;
			sel.moveStart('character', -1);
			sel.text='';
			myField.value.replace('&#001;', c);
			myField.value.replace('&amp;', '&');

			// Focus at pos
			pos+=len+before.length+after.length;
			this.focus();
			range=this.createTextRange();
			range.collapse(true);
			range.moveEnd('character', pos);
			range.moveStart('character', pos);
			range.select();
		} else {
			myField.value += before+after;
			myField.focus();
		}
	});
};

/**
 * This function creates a box in the page.
 *
 * @param string title: The box title
 * @param string content: The box content
 * @param mixed func: The function to use when ok pressed
 */
function bbtBox(title, content, func) {
	overlay=document.createElement('div');
	$(overlay).addClass('bbt_overlay').css('opacity', 0.8).appendTo('body').click(bbtCloseBox);

	box=$(document.createElement('div')).addClass('bbt_box').css('opacity', 1.0).appendTo('body');

	h4=$(document.createElement('h4')).html(title).appendTo(box);
	content=$(document.createElement('div')).addClass('content').html(content).appendTo(box);
	close=$(document.createElement('div')).addClass('close').appendTo(box);

	cancel=$(bbtCreateButton('~~boxok~~', 'bbt_ok', '~~boxok~~')).click(function() {
		func();
		bbtCloseBox();
	}).appendTo(close);
	cancel=$(bbtCreateButton('~~boxcancel~~', 'bbt_cancel', '~~boxcancel~~')).click(bbtCloseBox).appendTo(close);

	$(overlay).fadeIn(300);
	$(box).fadeIn(300);
	$(document).keypress(bbtEsc);
}

/**
 * This function closes the box.
 */
function bbtCloseBox() {
	$('.bbt_overlay, .bbt_box').fadeOut(300, function() {
		$('.bbt_overlay, .bbt_box').remove();
	});
	$(document).unbind('keypress', bbtEsc);	
}

/**
 * This function handles the keys when there is a box opened.
 * If the esc button is pressed, it closes the box.
 *
 * @param object event: The event object
 * @return boolean
 */
function bbtEsc(event) {
	if(event.keyCode==27) {
		bbtCloseBox();
		return false;
	} else if(event.keyCode==13 && $('.bbt_box input:focus').length>0) {
		$('input[name=bbtoolbar_bbt_ok]').trigger('click');
		return false;
	}

	return true;
}

/**
 * This function manages the URL box.
 *
 * @param string target: The target textarea 
 */
function bbtUrlBox(target) {
	nl="\n";
	content='<form action="#">'+nl;
	content+='<p><label for="bbturl">~~urlboxinsert~~</label>'+nl;
	content+='<input id="bbturl" name="bbturl" /></p>'+nl;
	content+='<p>~~urlboxatt~~</p>'+nl;
	
	if(bbtattachs.length==0) {
		content+='<p>~~urlbotnoatt~~</p>';
	} else {
		content+='<ul class="attachs_list">'+nl;
		for(i=0; i<bbtattachs.length; i++) {
			content+='<li>'+bbtattachs[i]+'</li>'+nl;
		}
		content+='</ul>';
	}

	content+=nl+'</form>';

	bbtBox('~~urlboxt~~', content, function() {
		url='';
		urlval=$('#bbturl').val();
		if(urlval!='') {
			url=urlval;
		} else if($('.bbt_box .attachs_list .sel').length>0) {
			url=$('.bbt_box .attachs_list .sel').text();
		} else {
			return;
		}
		$(target).insertAtCursor('[url=attachs/'+url+']', '[/url]');
		url=null;
	});

	bbtAttachmentsClick();
}

/**
 * This function manages the Img box.
 *
 * @param string target: The target textarea 
 */
function bbtImgBox(target) {
	nl="\n";
	content='<form action="#">'+nl;
	// The url
	content+='<fieldset><legend>~~imgsource~~</legend>'+nl;
	content+='<p><label for="bbturl">~~imgurl~~</label>'+nl;
	content+='<input id="bbturl" name="bbturl" /></p>'+nl;
	if(bbtattachs.length>0) {
		content+='<p>~~imglist~~</p>';
		content+='<ul class="attachs_list">'+nl;
		for(i=0; i<bbtimages.length; i++) {
			content+='<li>'+bbtimages[i]+'</li>'+nl;
		}
		content+='</ul>';
	}
	content+='</fieldset>'+nl;

	// Options fieldset
	content+='<fieldset><legend>~~imgoptions~~</legend>'+nl;

	// The float
	content+='<p><label for="bbtfloat">~~imgfloat~~</label>'+nl;
	content+='<select id="bbtfloat" name="bbtfloat">'+nl;
	content+='<option value="none">~~none~~</option>'+nl;
	content+='<option value="left">~~left~~</option>'+nl;
	content+='<option value="right">~~right~~</option>'+nl;
	content+='</select></p>'+nl;

	// Scale
	content+='<p><label for="bbtscale">~~imgscale~~</label>'+nl;
	content+='<input id="bbtscale" name="bbtscale" /></p>'+nl;

	// Width
	content+='<p><label for="bbtwidth">~~imgwidth~~</label>'+nl;
	content+='<input id="bbtwidth" name="bbtwidth" /></p>'+nl;

	// Height
	content+='<p><label for="bbtheight">~~imgheight~~</label>'+nl;
	content+='<input name="bbtheight" id="bbtheight" /></p>'+nl;

	// Popup
	content+='<p><label for="bbtpopup">~~imgpopup~~</label>'+nl;
	content+='<input value="yes" name="bbtpopup" id="bbtpopup" type="checkbox" /></p>'+nl;

	content+='</fieldset></form>';

	bbtBox('~~imgboxt~~', content, function() {
		options='';

		src=$('#bbturl').val();
		if(src=='' && $('.bbt_box .attachs_list .sel').length>0) {
			src='images/'+$('.bbt_box .attachs_list .sel').text();
		} else if(src=='') {
			return;
		}

		value=$('#bbtfloat').val();
		if(value!='' && value!='none') {
			options+=' float='+value;
		}

		value=$('#bbtscale').val();
		if(value!='') {
			options+=' scale='+value;
		}

		value=$('#bbtwidth').val();
		if(value!='') {
			options+=' width='+value;
		}

		value=$('#bbtheight').val();
		if(value!='') {
			options+=' height='+value;
		}

		value=$('#bbtpopup').val();
		if(value=='on' || value=='yes') {
			options+=' popup=true';
		}

		$(target).insertAtCursor('[img='+src+options+']', '', false);
	});

	bbtAttachmentsClick();
}

/**
 * This function adds the click events on the attachments list.
 */
function bbtAttachmentsClick(empty) {
	$('.bbt_box .attachs_list li').click(function() {
		$('.bbt_box .attachs_list .sel').removeClass('sel');
		$(this).addClass('sel');
		urlval=$('#bbturl').attr('value', '');
		return false;
	});

	$('.bbt_box .attachs_list li').dblclick(function() {
		$(this).trigger('click');
		$('input[name=bbtoolbar_bbt_ok]').trigger('click');
		return false;
	});
}

==> bbtoolbar_v1.1.tar.gz: bbtoolbar/res/bbtoolbar.js <==
//## DEFAULT CONFIG
bbtConfiguration={
	'enEn' : true,
	'enCo' : true,
	'emEnTB' : true,
	'emCoTB' : true,
	'emSet' : '',
	'blog_url' : './',
	'plugin_url' : './fp-plugins/bbtoolbar/',
	'tag' : false
};
bbtEmoticons={
}
//## EOF DEFAULT CONFIG

/**
 * This function creates a button with the standard DOM.
 *
 * @param string value: The value of the button
 * @param string name: The name of the button
 * @param string title: The title of the button
 * @return object: The button
 */
function bbtCreateButton(value, name, title) {
	name='bbtoolbar_'+name;

	button=document.createElement('input');
	button.setAttribute('value', value);
	button.setAttribute('name', name);
	button.setAttribute('title', title);
	button.setAttribute('type', 'button');

	return button;
}

/**
 * This function is the onclick handler for the buttons.
 */
function bbtOnclick() {
	// The pressed tag
	tag=$(this).attr('name').substr(10);

	// The target textarea
	target='textarea#content';

	if('undefined'!=typeof bbtCustomFunctions) {
		if(tag in bbtCustomFunctions) {
			if(!bbtCustomFunctions[tag](target)) {
				return false;
			}
		}
	}

	/*
	 * Complicated tags:
	 * color
	 * size
	 * url
	 * img
	 * video
	 * list --> Not implemented
	 * * --> Not implemented
	 * align
	 */
	switch(tag) {
		case 'img':
			bbtImgBox(target);
			break;
		case 'url':
			bbtUrlBox(target);
			break;
		default:
			$(target).insertAtCursor('['+tag+']', '[/'+tag+']');
			break;
	}

	return false;
}

/**
 * This function creates the toolbar of the comments.
 *
 * @param mixed target: The target of the form
 */
function bbtCommentToolbar(target) {
	// Create the place where insert buttons
	newelements=$('<div class="bbtoolbar comm_toolbar"></div>');
	newelements.insertBefore(target);

	buttons=[
		bbtCreateButton('B', 'b', '~~bold~~'), 
		bbtCreateButton('I', 'i', '~~italic~~'),
		bbtCreateButton('U', 'u', '~~underline~~'),
		bbtCreateButton('Del', 'del', '~~del~~'),
		bbtCreateButton('Quote', 'quote', '~~quote~~'),
		bbtCreateButton('Code', 'code', '~~code~~'),
	]

	if('undefined'!=typeof bbtCustomComment) {
		buttons=buttons.concat(bbtCustomComment);
	}

	// IE Complains. Fuck IE!
	//$(buttons).click(bbtOnclick).appendTo(newelements);
	$(buttons).each(function() {
			$(this).click(bbtOnclick)
		}).appendTo(newelements);
}

/**
 * This function creates the toolbar of the admin panel.
 */
function bbtAdminToolbar() {
	// Create the place where insert buttons
	newelements=$('<div class="bbtoolbar admin_toolbar"></div>');
	newelements.appendTo('.bbtoolbar_placeholder');

	buttons=[
		bbtCreateButton('B', 'b', '~~bold~~'), 
		bbtCreateButton('I', 'i', '~~italic~~'),
		bbtCreateButton('U', 'u', '~~underline~~'),
		bbtCreateButton('Del', 'del', '~~del~~'),
		bbtCreateButton('Quote', 'quote', '~~quote~~'),
		bbtCreateButton('Code', 'code', '~~code~~'),
		bbtCreateButton('Img', 'img', '~~image~~'),
		bbtCreateButton('URL', 'url', '~~url~~'),
		// 'hr','h2','h3','h4','h5','h6' --> I won't do them
		// list, * --> I won't do them
		// video --> I won't to it
		// align, color, size --> Should I do them?
	]

	if(bbtConfiguration.tag) {
		buttons[buttons.length]=bbtCreateButton('Tag', 'tag', '~~tag~~');
	}

	if('undefined'!=typeof bbtCustomAdmin) {
		buttons=buttons.concat(bbtCustomAdmin);
	}

	// IE Complains. Fuck IE!
	//$(buttons).click(bbtOnclick).appendTo(newelements);
	$(buttons).each(function() {
			$(this).click(bbtOnclick)
		}).appendTo(newelements);
}

/**
 * This function is the handler for the event
 * click of the emoticons.
 */
function bbtEclick() {
	alt=$(this).attr('alt');
	$('textarea#content').insertAtCursor(' '+alt+' ', '', false);
}

/**
 * This function creates the toolbar of the emoticons.
 *
 * @param mixed where: Where to add it.
 */
function bbtEmoticonsList(where) {
	if($(where).length<1) {
		return;
	}

	newelements=$('<div class="bbtoolbar emo_toolbar"></div>');

	for(i in bbtEmoticons) {
		image=document.createElement('img');
		image.setAttribute('alt', i);
		image.setAttribute('title', i);
		image.setAttribute('src', bbtConfiguration.plugin_url+'e_'+bbtConfiguration.emSet+'/'+bbtEmoticons[i]);
		$(image).click(bbtEclick).appendTo(newelements);
	}

	$(where).replaceWith(newelements);
}

/**
 * We start all the mechanism just when dom is ready.
 */
window.jQuery(document).ready(function() {
	// It's better making the search once
	isComment=$('#commentform').length>0;

	// The comments target: this is because of two different forms!
	target=$('#commentform .comment-content');
	alt_target=$('#commentform fieldset[id!=comment-userdata]:first');
	if(target.length==0 && alt_target.length>0) {
		target=alt_target;
	}

	if(isComment && bbtConfiguration.enCo) {
		bbtCommentToolbar(target);
	}

	if(isComment && bbtConfiguration.emCoTB) {
		placeholder=$('<div></div>').insertBefore(target);
		bbtEmoticonsList(placeholder);
	}

	// Same as above
	isAdmin=$('form[name=admin_entry_write]').length>0;

	if(isAdmin && bbtConfiguration.enEn) {
		bbtAdminToolbar();
	}

	if(isAdmin && bbtConfiguration.emEnTB) {
		placeholder=$('<div></div>').appendTo('.bbtoolbar_placeholder');
		bbtEmoticonsList(placeholder);
	}

});

/**
 * This function adds the text to the current position of the cursor.
 *
 * Thanks to phpMyAdmin that wrote it in js/functions.js
 * Thanks also to http://www.devland.it/cs/blogs/marco-del-gatto/archive/
 *    2010/09/14/funzione-jquery-per-inserire-testo-alla-posizione-del-cursore-di-una-textarea.aspx
 * because it didn't work without the $(this).each.
 * Thanks also to http://stackoverflow.com/questions/499126/jquery-set-cursor-position-in-text-area
 * because I've taken from here the position of the cursor.
 * Thanks also to http://web.archive.org/web/20080214051356/http://www.csie.ntu.edu.tw/~b88039/
 * html/jslib/caret.html : it helped me a lot with the Internet Explorer support
 *
 * @param string before: The text to insert before
 * @param string after: The text to insert after
 * @param boolean preserve: Preserve the selection? By default true
 */
window.jQuery.fn.insertAtCursor=function(before, after, preserve) {
	preserve=preserve!=false && undefined!=typeof preserve;

	$(this).each(function() {
		myField=this;

		if(myField.selectionStart || myField.selectionStart==0) {
			//MOZILLA/NETSCAPE and DOM support
			var startPos = myField.selectionStart;
			var endPos = myField.selectionEnd;

			if(startPos==0 && endPos==0) {
				startPos=myField.value.length;
				endPos=myField.value.length;
			}

			startText=myField.value.substring(0, startPos);
			endText=myField.value.substring(endPos, myField.value.length);

			if(startPos==endPos || !preserve) {
				current='';
				pos=-after.length;
			} else {
				current=myField.value.substring(startPos, endPos);
				pos=current.length;
			}

			myField.value=startText+before+current+after+endText;

			pos+=startPos+before.length+current.length+after.length;
			myField.focus();
			myField.setSelectionRange(pos, pos)
		} else if(document.selection) {
			// IE Support
			myField.focus();
			sel = document.selection.createRange();
			
			if(sel.text.length==0 || !preserve) {
				current='';
				pos=-after.length;
			} else {
				current=sel.text;
				pos=current.length;
			}

			sel.text = before+current+after;

			// Get the position of the cursor
			var c="\001", dul=sel.duplicate(), len=0;
			myField.value.replace('&', '&amp;');
			myField.value.replace(c, '&#001;');
			dul.moveToElementText(myField);
			sel.text=c;
			len=dul.text.indexOf(c)+1;
			sel.moveStart('character', -1);
			sel.text='';
			myField.value.replace('&#001;', c);
			myField.value.replace('&amp;', '&');

			// Focus at pos
			pos+=len+before.length+after.length;
			this.focus();
			range=this.createTextRange();
			range.collapse(true);
			range.moveEnd('character', pos);
			range.moveStart('character', pos);
			range.select();
		} else {
			myField.value += before+after;
			myField.focus();
		}
	});
};

/**
 * This function creates a box in the page.
 *
 * @param string title: The box title
 * @param string content: The box content
 * @param mixed func: The function to use when ok pressed
 */
function bbtBox(title, content, func) {
	overlay=document.createElement('div');
	$(overlay).addClass('bbt_overlay').css('opacity', 0.8).appendTo('body').click(bbtCloseBox);

	box=$(document.createElement('div')).addClass('bbt_box').css('opacity', 1.0).appendTo('body');

	h4=$(document.createElement('h4')).html(title).appendTo(box);
	content=$(document.createElement('div')).addClass('content').html(content).appendTo(box);
	close=$(document.createElement('div')).addClass('close').appendTo(box);

	cancel=$(bbtCreateButton('~~boxok~~', 'bbt_ok', '~~boxok~~')).click(function() {
		func();
		bbtCloseBox();
	}).appendTo(close);
	cancel=$(bbtCreateButton('~~boxcancel~~', 'bbt_cancel', '~~boxcancel~~')).click(bbtCloseBox).appendTo(close);

	$(overlay).fadeIn(300);
	$(box).fadeIn(300);
	$(document).keypress(bbtEsc);
}

/**
 * This function closes the box.
 */
function bbtCloseBox() {
	$('.bbt_overlay, .bbt_box').fadeOut(300, function() {
		$('.bbt_overlay, .bbt_box').remove();
	});
	$(document).unbind('keypress', bbtEsc);	
}

/**
 * This function handles the keys when there is a box opened.
 * If the esc button is pressed, it closes the box.
 *
 * @param object event: The event object
 * @return boolean
 */
function bbtEsc(event) {
	if(event.keyCode==27) {
		bbtCloseBox();
		return false;
	} else if(event.keyCode==13 && $('.bbt_box input:focus').length>0) {
		$('input[name=bbtoolbar_bbt_ok]').trigger('click');
		return false;
	}

	return true;
}

/**
 * This function manages the URL box.
 *
 * @param string target: The target textarea 
 */
function bbtUrlBox(target) {
	nl="\n";
	content='<form action="#">'+nl;
	content+='<p><label for="bbturl">~~urlboxinsert~~</label>'+nl;
	content+='<input id="bbturl" name="bbturl" /></p>'+nl;
	content+='<p>~~urlboxatt~~</p>'+nl;
	
	if(bbtattachs.length==0) {
		content+='<p>~~urlbotnoatt~~</p>';
	} else {
		content+='<ul class="attachs_list">'+nl;
		for(i=0; i<bbtattachs.length; i++) {
			content+='<li>'+bbtattachs[i]+'</li>'+nl;
		}
		content+='</ul>';
	}

	content+=nl+'</form>';

	bbtBox('~~urlboxt~~', content, function() {
		url='';
		urlval=$('#bbturl').val();
		if(urlval!='') {
			url=urlval;
		} else if($('.bbt_box .attachs_list .sel').length>0) {
			url=$('.bbt_box .attachs_list .sel').text();
		} else {
			return;
		}
		$(target).insertAtCursor('[url=attachs/'+url+']', '[/url]');
		url=null;
	});

	bbtAttachmentsClick();
}

/**
 * This function manages the Img box.
 *
 * @param string target: The target textarea 
 */
function bbtImgBox(target) {
	nl="\n";
	content='<form action="#">'+nl;
	// The url
	content+='<fieldset><legend>~~imgsource~~</legend>'+nl;
	content+='<p><label for="bbturl">~~imgurl~~</label>'+nl;
	content+='<input id="bbturl" name="bbturl" /></p>'+nl;
	if(bbtattachs.length>0) {
		content+='<p>~~imglist~~</p>';
		content+='<ul class="attachs_list">'+nl;
		for(i=0; i<bbtimages.length; i++) {
			content+='<li>'+bbtimages[i]+'</li>'+nl;
		}
		content+='</ul>';
	}
	content+='</fieldset>'+nl;

	// Options fieldset
	content+='<fieldset><legend>~~imgoptions~~</legend>'+nl;

	// The float
	content+='<p><label for="bbtfloat">~~imgfloat~~</label>'+nl;
	content+='<select id="bbtfloat" name="bbtfloat">'+nl;
	content+='<option value="none">~~none~~</option>'+nl;
	content+='<option value="left">~~left~~</option>'+nl;
	content+='<option value="right">~~right~~</option>'+nl;
	content+='</select></p>'+nl;

	// Scale
	content+='<p><label for="bbtscale">~~imgscale~~</label>'+nl;
	content+='<input id="bbtscale" name="bbtscale" /></p>'+nl;

	// Width
	content+='<p><label for="bbtwidth">~~imgwidth~~</label>'+nl;
	content+='<input id="bbtwidth" name="bbtwidth" /></p>'+nl;

	// Height
	content+='<p><label for="bbtheight">~~imgheight~~</label>'+nl;
	content+='<input name="bbtheight" id="bbtheight" /></p>'+nl;

	// Popup
	content+='<p><label for="bbtpopup">~~imgpopup~~</label>'+nl;
	content+='<input name="bbtpopup" id="bbtpopup" type="checkbox" /></p>'+nl;

	content+='</fieldset></form>';

	bbtBox('~~imgboxt~~', content, function() {
		options='';

		src=$('#bbturl').val();
		if(src=='' && $('.bbt_box .attachs_list .sel').length>0) {
			src='images/'+$('.bbt_box .attachs_list .sel').text();
		} else if(src=='') {
			return;
		}

		value=$('#bbtfloat').val();
		if(value!='' && value!='none') {
			options+=' float='+value;
		}

		value=$('#bbtscale').val();
		if(value!='') {
			options+=' scale='+value;
		}

		value=$('#bbtwidth').val();
		if(value!='') {
			options+=' width='+value;
		}

		value=$('#bbtheight').val();
		if(value!='') {
			options+=' height='+value;
		}

		if($('#bbtpopup:checked').length) {
			options+=' popup=true';
		}

		$(target).insertAtCursor('[img='+src+options+']', '', false);
	});

	bbtAttachmentsClick();
}

/**
 * This function adds the click events on the attachments list.
 */
function bbtAttachmentsClick(empty) {
	$('.bbt_box .attachs_list li').click(function() {
		$('.bbt_box .attachs_list .sel').removeClass('sel');
		$(this).addClass('sel');
		urlval=$('#bbturl').attr('value', '');
		return false;
	});

	$('.bbt_box .attachs_list li').dblclick(function() {
		$(this).trigger('click');
		$('input[name=bbtoolbar_bbt_ok]').trigger('click');
		return false;
	});
}
